// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KRUNNER_VERSION_H
#define KRUNNER_VERSION_H

#define KRUNNER_VERSION_STRING "5.115.0"
#define KRUNNER_VERSION_MAJOR 5
#define KRUNNER_VERSION_MINOR 115
#define KRUNNER_VERSION_PATCH 0
#define KRUNNER_VERSION ((5<<16)|(115<<8)|(0))

#endif
